==> WHLX_CMS-0.01alpha.zip: whlx/library/domxml.php <==
<?php
// 
// WHLX CMS - domxml.php
// 
// 20040330 - 0.00 alpha
// 20040401 - 0.01 alpha    追加:WHLX_DomXML_CreateComment
// 20040402 - 0.02 alpha    名称変更:whlx_domxml.php -> domxml.php etc. 
// 




function  WHLX_DomXML_NewDocument  ( $version )
{
	// $root =  domxml_new_doc( $version );    // 新しいPHPでは対応していないかもしれません. 
	$root =  domxml_new_xmldoc( $version );    // 古いPHPではこっちかな. 
	return $root;
}


function  WHLX_DomXML_RegisterXSLT ( $document, $xslt, $version, $type, $encoding )
{
	$content =  
		'href="'.        $xslt.        '" '.    
		'version="'.     $version.     '" '.    
		'type="'.        $type.        '" '.    
		'encoding="'.    $encoding.    '" ';    

	$pi =  $document->create_processing_instruction( 'xml-stylesheet', $content );
	$document->add_child( $pi );

	return $content;
}


function  WHLX_DomXML_RegisterChild( $document, $parent, $child, $content )
{
	$parent->add_child  ( $child   );
	$child ->set_content( $content );
}


function  WHLX_DomXML_CreateChild  ( $document, $parent, $label, $content )
{
	$child =  $document->create_element( $label   );
	$parent->add_child  ( $child   );

	if( $content == '' || $content == null ) return $child;

//	$text =  $document->create_text_node( $content );
//	$child ->add_child  ( $text    );
	$child ->set_content( $content );

	return $child;
}


function  WHLX_DomXML_CreateComment( $document, $parent, $content )
{
	$child =  $document->create_comment( $content );
	$parent->add_child  ( $child   );
	return $child;
}


function  WHLX_DomXML_Output       ( $document, $name, $mode )
{
	$data =  $document->dumpmem();
	$data =  str_replace( '><'    , ">\r\n<", $data );
	$data =  str_replace( '&lt;'  , '<'     , $data );
	$data =  str_replace( '&gt;'  , '>'     , $data );
	$data =  str_replace( '&quot;', '"'     , $data );
	$data =  str_replace( '&amp;' , '&'     , $data );

	if( $name == '' || $name == null || $mode == null ) return $data;

	$handle =  fopen( $name, 'w+' );
	if( $handle )
	{
		if( flock( $handle, LOCK_EX ) )
		{
			fwrite( $handle, $data );
			flock ( $handle, LOCK_UN );
		}
		fclose( $handle );
		chmod( $name, $mode );
	}

	return $data;
}




?>

==> WHLX_CMS-0.08alpha.zip: whlx/library/domxml.php <==
<?php
// 
// WHLX CMS - domxml.php
// 
// 20040330 - 0.00 alpha
// 20040401 - 0.01 alpha    追加:WHLX_DomXML_CreateComment
// 20040402 - 0.02 alpha    名称変更:whlx_domxml.php -> domxml.php etc. 
// 




function  WHLX_DomXML_NewDocument    ( $version )
{
	// $root =  domxml_new_doc( $version );    // 新しいPHPでは対応していないかもしれません. 
	$root =  domxml_new_xmldoc( $version );    // 古いPHPではこっちかな. 
	return $root;
}




function  WHLX_DomXML_RegisterXSLT   ( $document, $xslt, $version, $type, $encoding )
{
	$content =  
		'href="'.        $xslt.        '" '.    
		'version="'.     $version.     '" '.    
		'type="'.        $type.        '" '.    
		'encoding="'.    $encoding.    '" ';    

	$pi =  $document->create_processing_instruction( 'xml-stylesheet', $content );
	$document->add_child( $pi );

	return $content;
}




function  WHLX_DomXML_RegisterChild  ( $document, $parent, $child, $content )
{
	$parent->add_child  ( $child   );
	$child ->set_content( $content );
}




function  WHLX_DomXML_CreateChild    ( $document, $parent, $label, $content )
{
	$child =  $document->create_element( $label   );
	$parent->add_child  ( $child   );

	if( $content == '' || $content == null ) return $child;

//	$text =  $document->create_text_node( $content );
//	$child ->add_child  ( $text    );
	$child ->set_content( $content );

	return $child;
}




function  WHLX_DomXML_CreateComment  ( $document, $parent, $content )
{
	$child =  $document->create_comment( $content );
	$parent->add_child  ( $child   );
	return $child;
}




function  WHLX_DomXML_CreateAttribute( $document, $parent, $attribute_name, $attribute_value )
{
	$child =  $document->create_attribute( $attribute_name, $attribute_value );
	$parent->add_child  ( $child   );
	return $child;
}




function  WHLX_DomXML_Output         ( $document, $name, $mode )
{
	$data =  $document->dumpmem();
	$data =  str_replace( '><'    , ">\r\n<", $data );
//	$data =  str_replace( '&lt;'  , '<'     , $data );
//	$data =  str_replace( '&gt;'  , '>'     , $data );
//	$data =  str_replace( '&quot;', '"'     , $data );
//	$data =  str_replace( '&amp;' , '&'     , $data );

	if( $name == '' || $name == null || $mode == null ) return $data;

	$handle =  fopen( $name, 'w+' );
	if( $handle )
	{
		if( flock( $handle, LOCK_EX ) )
		{
			fwrite( $handle, $data );
			flock ( $handle, LOCK_UN );
		}
		fclose( $handle );
		chmod( $name, $mode );
	}

	return $data;
}




?>
